{"type":"rich","version":"1.0","title":"The Fishcake🐶🐾 wrote","author_name":"The Fishcake🐶🐾 (npub137…ak37w)","author_url":"https://nostr.now/npub137c5pd8gmhhe0njtsgwjgunc5xjr2vmzvglkgqs5sjeh972gqqxqjak37w","provider_name":"njump","provider_url":"https://nostr.now","html":"Looking back at 2024 and my adventure with nostr. I think I joined around February 12, in the same month after getting initial knowledge about Lightning, I started my first node around February 20. From then on, I started looking for the ways to contribute to the Nostr community and reached-out to nostr.build to help with the run-away costs of bandwidth. The rest as they say, is history.\n\nIn 2023 the following major changes happened to the nostr.build (only listing contributions that I made):\n- Complete re-architecture of the service, going from single to a multi-server setup\n- Rewrote the internal code more than once\n- Migrated from local storage (HDD) to the object storage\n- Created a dedicated API for uploads from the clients, and onboarded multiple clients onto it\n- Added support for NIP-98 (contributed code to Damus to allow for authenticated uploads)\n- Added support for NIP-96\n- Added multiple ways to login (NIP-98, NIP-07,NIP-04 [DMs])\n- Added optimization of the images, gifs and videos (only minimal repackaging for videos)\n- Open-sourced the code (rewrote so that all of the non-public info is not in the code)\n- Added support for multi-file uploads with folder support\n- Added support for URL upload for accounts\n- Rewrote and redesigned image view gallery\n- Redesigned sign-up and onboarding experience\n- Added support for on-the-fly image resizing\n- Added CDN, migrated to another CDN, added hot media object storage on the CDN\n- Fixed countless security and availability risks and issues\n- Countless quality-of-life improvements to the media uploads, serving, managing, etc.\n- Added more than 100K lines of code (20K of my own and 80K of libs) and removed about 10K-20K of legacy lines of code\n- Redesigned DB access layer and SQL queries more than once, trying to keep with the load\n- Reduced number of SQL queries by 90%, making access more efficient and fast\n- Reduced running costs by 95%, which directly translates to the savings of the users and viability of the service long-term.\n- And many other things that I just do not recall or were not impactful enough for me to remember.\n\nSince we have such a good base now, I am sure my contributions to the nostr media ecosystem will be 2-3 times bigger. Onwards and forward! 🐶🐾🫡🫂 nostr:note1u47936hr7p2rhzpexrf4ejmg78whzqs9r9zdzj9e40qh7p4m2p3s9gdvwa"}
